<?php


/**
 * @file
 * Class for comments_per_node metric.
 */

class  SamplerExampleMetricCommentsPerNode extends SamplerMetric {

  public function computeSample() {

    // Load options.
    $sample = $this->currentSample;

    $where_pieces = array();
    $args = array();

    // Add filters on node created time if they were set.
    if (!empty($sample->options['startstamp'])) {
      $where_pieces[] = "n.created > %d";
      $start = is_numeric($sample->options['startstamp']) ? $sample->options['startstamp'] : strtotime($sample->options['startstamp']);
      $args = array_merge($args, array($start));
    }
    if (!empty($sample->options['endstamp'])) {
      $where_pieces[] = "n.created < %d";
      $end = is_numeric($sample->options['endstamp']) ? $sample->options['endstamp'] : strtotime($sample->options['endstamp']);
      $args = array_merge($args, array($end));
    }

    // If a node type has been passed, restrict to that type.
    if (!empty($sample->options['node_type'])) {
      $where_pieces[] = "n.type = '%s'";
      $args = array_merge($args, array($sample->options['node_type']));
    }

    // Restrict to only the passed nids.
    if (!empty($sample->options['object_ids'])) {
      $where_pieces[] = "n.nid IN (". db_placeholders($sample->options['object_ids']) .")";
      $args = array_merge($args, $sample->options['object_ids']);
    }

    if (empty($where_pieces)) {
      $where = '';
    }
    else {
      $where = ' WHERE ' . implode(' AND ', $where_pieces);
    }

    // Pull the total entries in the comment table, grouped by nid.
    $nodes = db_query_slave("SELECT n.nid, COUNT(c.cid) AS count FROM {node} n LEFT JOIN {comments} c ON n.nid = c.nid$where GROUP BY n.nid", $args);

    while ($node = db_fetch_object($nodes)) {
      $this->currentSample->values[$node->nid]['comments'] = $node->count ? $node->count : 0;
    }
  }

  public function trackObjectIDs() {

    // Load options -- these are the global options in the sampler object.
    $options = $this->options;

    $where_pieces = array();
    $args = array();
    $object_ids = array();

    // If a node type has been passed, restrict to that type.
    if (!empty($options['node_type'])) {
      $where_pieces[] = "type = '%s'";
      $args = array_merge($args, array($options['node_type']));
    }

    if (empty($where_pieces)) {
      $where = '';
    }
    else {
      $where = ' WHERE ' . implode(' AND ', $where_pieces);
    }

    // Grab nids.
    $nodes = db_query_slave("SELECT nid FROM {node}$where", $args);

    while ($node = db_fetch_object($nodes)) {
      $object_ids[] = $node->nid;
    }

    return $object_ids;
  }
}
